@@ -4,8 +4,7 @@
 #'
 #' @name threejs-package
 #' @references
-#' \url{http://threejs.org}
-#' \url{http://www.html5rocks.com/en/tutorials/three/intro/}
+#' \url{https://threejs.org}
 #' @aliases threejs
 #' @examples
 #' \dontrun{
@@ -15,8 +14,9 @@
 #'
 #' # See also help for globe.js and scatterplot3.js
 #' }
-#' 
-#' @docType package
+#'
+# @docType package
+"_PACKAGE"
 NULL
 
 
